# Что это

mweather - бесплатное и быстрое погодное api, не требующее ключей.

## Установка

```sh
pip install -U mweather
```

## Описание функций

Функция weather - узнаёт текущую погоду в определенном городе.  
Параметры функции:  
city - укажите город, погоду которого вы хотите узнать.  
output - всего существует несколько значений (string; json; temp; weather).  
lang - язык, всего пока что доступных 2 языка (en; ru). [ВАЖНО! Если вы находитесь в Республике Молдове или Румынии то вместо Английского языка у вас будет Румынский]  

```python
weather(city="Нью Йорк", output="json", lang="ru")
# Вывод: {'weather': 'Облачно', 'temp': '9°C', 'response-time': 0.42}
```

## Примеры использования

```python
import mweather

output = mweather.weather(city="Нью Йорк", output="string", lang="ru")
print(output)

# Вывод: Облачно, 10°C
```

Напишем **простое** приложение:

```python
import mweather
from tkinter import messagebox

city = input('Введите город: ')
output = mweather.weather(city=city, output='string', lang='ru')
messagebox.showinfo(title='Погода', message=f'{city}: {output}')
```
На выводе получаем **это**:  
![Вывод](https://i.ibb.co/sbmk2KC/output-easy-app.png)

Напишем приложение чуть по **сложнее**, в котором будем использовать уже JSON:
```python
import mweather
from tkinter import messagebox

city = input('Введите город: ')
output = mweather.weather(city=city, output='json', lang='ru')
messagebox.showinfo(title='Погода', message=f'Погода в {city}\nТемпература: {output['temp']}.\nПогода: {output['weather']}.\nСкорость ответа: {output['response-time']}с.')
```
А уже здесь получаем это:  
![Вывод](https://i.ibb.co/Hpz3TYd/output-hard-app.png)
В этом приложении мы также можем узнать скорость ответа, введя ключ **'response-time'**.

Но ещё, есть ещё одно значение вывода (output), это - 'calendar', оно выводит погоду в формате календаря.
Пример:  
```python
import mweather

city = input('Введите город: ') # например, пусть будет - Кишинёв
output = mweather.weather(city=city, output='calendar', lang='ru')
print(output)
```
Получаем:  
```
Прогноз погоды: Кишинев

      \   /     Ясно
       .-.      9 °C
    ― (   ) ―   ↑ 4 км/ч
       `-’      10 км
      /   \     0.0 мм
                                                       ┌─────────────┐
┌──────────────────────────────┬───────────────────────┤ Вс. 07 апр. ├───────────────────────┬──────────────────────────────┐
│             Утро             │             День      └──────┬──────┘      Вечер            │             Ночь             │
├──────────────────────────────┼──────────────────────────────┼──────────────────────────────┼──────────────────────────────┤
│    \  /       Partly Cloudy  │    \  /       Partly Cloudy  │    \  /       Partly Cloudy  │     \   /     Clear          │
│  _ /"".-.     15 °C          │  _ /"".-.     19 °C          │  _ /"".-.     17 °C          │      .-.      14 °C          │
│    \_(   ).   ↓ 17-19 км/ч   │    \_(   ).   ↓ 16-19 км/ч   │    \_(   ).   ↓ 4-8 км/ч     │   ― (   ) ―   ↙ 4-9 км/ч     │
│    /(___(__)  10 км          │    /(___(__)  10 км          │    /(___(__)  10 км          │      `-’      10 км          │
│               0.0 мм | 0%    │               0.0 мм | 0%    │               0.0 мм | 0%    │     /   \     0.0 мм | 0%    │
└──────────────────────────────┴──────────────────────────────┴──────────────────────────────┴──────────────────────────────┘
                                                       ┌─────────────┐
┌──────────────────────────────┬───────────────────────┤ Пн. 08 апр. ├───────────────────────┬──────────────────────────────┐
│             Утро             │             День      └──────┬──────┘      Вечер            │             Ночь             │
├──────────────────────────────┼──────────────────────────────┼──────────────────────────────┼──────────────────────────────┤
│     \   /     Солнечно       │     \   /     Солнечно       │     \   /     Солнечно       │     \   /     Clear          │
│      .-.      17 °C          │      .-.      21 °C          │      .-.      19 °C          │      .-.      14 °C          │
│   ― (   ) ―   ↖ 8-9 км/ч     │   ― (   ) ―   ↑ 12-13 км/ч   │   ― (   ) ―   ↑ 11-20 км/ч   │   ― (   ) ―   ↑ 12-25 км/ч   │
│      `-’      10 км          │      `-’      10 км          │      `-’      10 км          │      `-’      10 км          │
│     /   \     0.0 мм | 0%    │     /   \     0.0 мм | 0%    │     /   \     0.0 мм | 0%    │     /   \     0.0 мм | 0%    │
└──────────────────────────────┴──────────────────────────────┴──────────────────────────────┴──────────────────────────────┘
                                                       ┌─────────────┐
┌──────────────────────────────┬───────────────────────┤ Вт. 09 апр. ├───────────────────────┬──────────────────────────────┐
│             Утро             │             День      └──────┬──────┘      Вечер            │             Ночь             │
├──────────────────────────────┼──────────────────────────────┼──────────────────────────────┼──────────────────────────────┤
│               Cloudy         │    \  /       Partly Cloudy  │     \   /     Солнечно       │     \   /     Clear          │
│      .--.     17 °C          │  _ /"".-.     21 °C          │      .-.      18 °C          │      .-.      13 °C          │
│   .-(    ).   ↖ 12-14 км/ч   │    \_(   ).   ↖ 15-18 км/ч   │   ― (   ) ―   ↖ 19-32 км/ч   │   ― (   ) ―   ↖ 12-24 км/ч   │
│  (___.__)__)  10 км          │    /(___(__)  10 км          │      `-’      10 км          │      `-’      10 км          │
│               0.0 мм | 0%    │               0.0 мм | 0%    │     /   \     0.0 мм | 0%    │     /   \     0.0 мм | 0%    │
└──────────────────────────────┴──────────────────────────────┴──────────────────────────────┴──────────────────────────────┘
Местоположение: Chișinău, Municipiul Chișinău, Moldova [47.0122737,28.8605936]
```
### Автор
**Telegram: [t.me/mc_c0rp](http://t.me/mc_c0rp "t.me/mc_c0rp")**